/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "คุณไม่มีสิทธิ์ของผู้ดูแลระบบใน HumanResources"

, "Working time model"
: ""

, "Book as vacation"
: "จองเป็นพักร้อน"

, "Sickness"
: "เจ็บป่วย"

, "Sickness Days"
: "วันที่ลาเจ็บป่วย"

, "Vacation"
: "พักร้อน"

, "Vacation Days"
: "วันพักร้อน"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: "ไม่สามารถจองเป็นพักร้อนได้"

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""

]
, "Title"
: "คำนำหน้าชื่อ"

, "Work Start"
: ""

, "Work End"
: ""

, "Edit {0} for {1} - {2}"
: "แก้ไข {0} สำหรับ {1} - {2}"

, "Extra free time, Extra free times"
: [
  "เวลาว่างพิเศษ"

]
, "Summary"
: "ข้อสรุป"

, "Free Times"
: "เวลาที่ว่าง"

, "Possible vaction days"
: "วันกร้อนที่เป็นไปได้"

, "Remaining vaction days"
: "วันพักร้อนที่คงค้าง"

, "Taken vaction days"
: "วันพักร้อนที่ใช้ไป"

, "Expired vaction days"
: "วันพักร้อนที่หมดสิทธิ์แล้ว"

, "Rebooked vaction days"
: "วันพักร้อนที่ได้จองอีกรอบ"

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: "วันที่ทำงาน"

, "Hours to work"
: "ชั่วโมงที่ทำงาน"

, "Days to work after vacation and sickness"
: "วันที่ทำงานหลังจากลาพักร้อนและเจ็บป่วย"

, "Hours to work after vacation and sickness"
: "ชั่วโมงที่ทำงานหลังจากลาพักร้อนและเจ็บป่วย"

, "Miscellaneous"
: "เบ็ดเตล็ด"

, "Description"
: "การอธิบาย"

, "Working time Model"
: ""

, "Work start"
: ""

, "not set"
: ""

, "Work end"
: ""

, "Working Hours per week"
: "ชั่วโมงทำงานต่อสัปดาห์"

, "Mon."
: "จ"

, "Tue."
: "อังคาร"

, "Wed."
: "พุธ"

, "Thu."
: "พฤ."

, "Fri."
: "ศ."

, "Sat."
: "ส."

, "Sun."
: "อา."

, "Employee, Employees"
: [
  "ลูกจ้าง"

]
, "Cancel"
: "ยกเลิก"

, "OK"
: "ตกลง"

, "Please use the following format: MM-DD"
: "กรุณาใช้รูปแบบดังต่อไปนี้: MM-DD"

, "Calendar"
: "ปฏิทิน"

, "Calendars"
: "ปฏิทิน"

, "Vacation expires"
: "พักร้อนหมด"

, "Breaks"
: ""

, "Hours"
: ""

, "Break duration"
: ""

, "Book remaining vacation"
: "จองพักร้อนที่คงค้าง"

, "Year"
: "ปี"

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: "สร้าง บัญชีใหม่"

, "Booking has been successfull!"
: "ประสบความสำเร็จในการจอง!"

, "The remaining vacation days of the selected accounts have been booked successfully!"
: "วันพักร้อนที่คงค้างของบัญชีที่เลือกนั้นได้ทำการจองแล้วเรียบร้อย!"

, "CostCenter, CostCenters"
: [
  "ศูนย์ต้นทุน"

]
, "Cost Center, Cost Centers"
: [
  "ศูนย์ต้นทุน"

]
, "Startdate"
: "วันเริ่ม"

, "Contract, Contracts"
: [
  "สัญญา"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: "แก้ไข {0}"

, "Start Date"
: "วันที่เริ่มต้น"

, "End Date"
: "วันที่สิ้นสุด"

, "Feast Calendar"
: "ปฏิทินงานเทศกาล"

, "Choose the template"
: "เลือกแม่แบบ ..."

, "Vacation days of one calendar year"
: "วันพักร้อนของหนึ่งปีปฏิทิน"

, "Edit {0} \"{1}\""
: "แก้ไข {0} \"{1}\""

, "Edit {0} for {1}"
: "แก้ไข {0} สำหรับ {1}"

, "Add {0} for {1}"
: "เพิ่ม {0} สำหรับ {1}"

, "You have to select at least one day to save this sickness entry."
: "คุณต้องเลือกอย่างน้อยหนึ่งวันเพื่อบันทึกการเจ็บป่วยครั้งนี้"

, "You have to select at least one day to save this vacation entry."
: "คุณต้องเลือกอย่างน้อยหนึ่งวันเพื่อบันทึกการพักร้อนครั้งนี้"

, "No day selected"
: "ไม่ได้เลือกวันใด ๆ"

, "Personal account, Personal accounts"
: [
  "บัญชีส่วนตัว"

]
, "Status"
: "สถานะ"

, "Remaining"
: "คงค้าง"

, "Select Days"
: "เลือก วัน"

, "Enter description"
: "ใส่ คำอธิบาย"

, "Account is disabled or deleted!"
: ""

, "Division"
: "แผนก"

, "Health Insurance"
: "ประกันสุขภาพ"

, "Apply contact data on form"
: "ใช้ข้อมูลการติดต่อบนแบบฟอร์ม"

, "Salutation"
: "คำขึ้นต้น"

, "Personal Information"
: "ข้อมูลส่วนตัว"

, "Country"
: "ประเทศ"

, "Birthday"
: "วันเกิด"

, "Internal Information"
: "ข้อมูลภายใน"

, "Banking Information"
: "ข้อมูลธนาคาร"

, "Days"
: "วัน"

, "Type"
: "ประเภท"

, "Expiration date"
: "หมดเขตวันที่"

, "WK"
: "สัปดาห์"

, "Loading calendar data..."
: "กำลังโหลดข้อมูลปฏิทิน..."

, "Year can not be changed"
: "ปีไม่สามารถเปลี่ยนได้"

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: "ไม่มีวันพักร้อนแล้ว"

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: ""

, "Unexcused"
: ""

, "Currently employed"
: "ถูกว่าจ้างในเวลานี้"

, "Employees which are currently employed"
: "ลูกจ้างที่กำลังถูกว่าจ้าง"

, "All employees"
: "ลูกจ้างทั้งหมด"

, "All available employees"
: "ลูกจ้างทั้งหมดที่ว่างอยู่"

, "Payed"
: "จ่ายแล้ว"

, "Not payed"
: "ไม่ได้จ่าย"

, "Currently employed employees"
: "ลูกจ้างที่ถูกว่าจ้างในเวลานี้"

, "All accounts"
: "บัญชีทั้งหมด"

, "All available accounts"
: "บัญชีทั้งหมดที่มีอยู่"

, "Full-time 40 hours"
: "เต็มเวลา 40 ชั่วโมง"

, "Full-time 37.5 hours"
: "เต็มเวลา 37.5 ชั่วโมง"

, "Part-time 20 hours"
: ""

, "Freetime Type"
: "ประเภท เวลาว่าง"

, "Possible free time definitions"
: "จำกัดความเรื่องเวลาว่างที่เป็นไปได้"

, "Vacation Status"
: "สถานะ การพักร้อน"

, "Possible vacation status definitions"
: "จำกัดความสถานะการพักร้อนที่เป็นไปได้"

, "Requested"
: "ได้ทำเรื่องขอ"

, "In process"
: "อยู่ระหว่างดำเนินการ"

, "Accepted"
: "ได้อนุมัติแล้ว"

, "Declined"
: "ได้ปฏิเสธแล้ว"

, "Sickness Status"
: "สถานะ เจ็บป่วย"

, "Possible sickness status definitions"
: "จำกัดความเรื่องสถานะของการอาจจะเกิดการเจ็บป่วย"

, "Default Feast Calendar"
: "ปฏิทินงานเทศกาลหลัก"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "ตรงนี้คุณสามารถจำกัดปฏิทินงานเทศกาลหลักเพื่อใช้เป็นตัวตั้งวันฉลองและวันหยุดอื่น ๆ ได้"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: "ประเภท เวลาว่างพิเศษ"

, "Possible extra free time definitions"
: "จำกัดความเรื่องเวลาว่างพิเศษที่เป็นไปได้"

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: "ตรงนี้คุณสามารถจำกัดวันได้ เมื่อวันพักร้อนของปีก่อนได้นำมาใช้ รูปแบบจะเป็น MM-DD"

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Paid Absence Time"
: ""

, "Unpaid Absence Time"
: ""

, "Absence"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Feast Time"
: ""

, "Break Time"
: ""

, "Sickness Time"
: ""

, "Working Time Correction"
: ""

, "Actual Working Time"
: ""

, "Target Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Cleared in"
: ""

, "Working time, Working times"
: [
  ""

]
, "Quick search"
: "ค้นหาอย่างรวดเร็ว"

, "Extra free times"
: "เวลาว่างพิเศษ"

, "Free Time, Free Times"
: [
  "เวลาที่ว่าง"

]
, "Account"
: "บัญชี"

, "First Day"
: "วันแรก"

, "Last Day"
: "วันสุดท้าย"

, "Days Count"
: "นับวัน"

, "Free Days"
: "วันหยุด"

, "Private Information"
: "ข้อมูลส่วนตัว"

, "Is employed"
: "ถูกว่าจ้าง"

, "Number"
: "หมายเลข"

, "Badge Id"
: ""

, "Germany"
: "เยอรมนี"

, "Locality"
: "ถิ่นที่อยู่"

, "Postalcode"
: "รหัสไปรษณีย์"

, "Region"
: "เขต"

, "Street"
: "ถนน"

, "Street 2"
: "ถนน 2"

, "E-Mail"
: "อีเมล"

, "Telephone Number"
: "หมายเลขโทรศัพท์"

, "Cell Phone Number"
: "หมายเลขโทรศัพท์เคลื่อนที่"

, "Last Name"
: "นามสกุล"

, "First Name"
: "ชื่อตัว"

, "Employee name"
: "ชื่อลูกจ้าง"

, "Account Holder"
: "เจ้าของบัญชี"

, "Account Number"
: "หมายเลขบัญชี"

, "Bank Name"
: "ชื่อธนาคาร"

, "Code Number"
: "หมายเลขรหัส"

, "Employment begin"
: "การจ้างงาน เริ่ม"

, "Employment end"
: "การจ้างงาน สิ้นสุด"

, "Supervisor"
: "หัวหน้า"

, "Profession"
: "วิชาชีพ"

, "Position"
: "ตำแหน่ง"

, "Contracts"
: ""

, "Cost Centers"
: "ศูนย์ต้นทุน"

, "Free Day, Free Days"
: [
  "วันหยุด"

]
, "Break, Breaks"
: [
  ""

]
, "Workingtime"
: "เวลาทำงาน"

, "No contract could be found."
: "ไม่พบข้อมูล"

, "Please create a contract for this employee!"
: "กรุณาสร้างสัญญาการจ้างให้ลูกจ้างคนนี้!"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: "วันเริ่มในสัญญาการจ้างต้องอยู่ก่อนวันสิ้นสุดการว่าจ้าง!"

, "Not allowed!"
: "ไม่ได้รับอนุญาต!"

, "It's only allowed to book remaining vacation days from years in the past!"
: "อนุญาตให้จองวันพักร้อนจากปีที่ผ่านมาเท่านั้น!"

, "Contracts overlap"
: "สัญญาซ้อนทับกัน"

, "The contracts must not overlap!"
: "สัญญาต้องไม่ซ้อนทับกัน!"

, "No or no valid year given"
: "ไม่มี หรือ ไม่ได้ให้ปีที่ถูกต้องมา"

, "Please use a valid year!"
: "กรุณาใช้ปีที่ถูกต้อง"

, "No current contract!"
: "ไม่มีสัญญาตอนนี้"

, "A current contract could not be found!"
: "สัญญาตอนนี้หาไม่พบ!"

, "Contract not editable"
: "สัญญาว่าจ้างไม่สามารถแก้ไขได้"

, "You are not allowed to change the record if a vacation has been booked already!"
: "คุณไม่สามารถเปลี่ยนบันทึกได้ กรณีที่มีการจองวันพักร้อนเรียบร้อยแล้ว!"

, "No personal account found"
: "ไม่พบบัญชีส่วนตัว"

, "An existing personal account could not be found. Please create one!"
: "บัญชีส่วนตัวที่มีอยู่ค้นหาไม่พบ กรุณาสร้างบัญชีใหม่!"

, "edit private employee data"
: "แก้ไขข้อมูลลูกจ้างที่เป็นเรื่องส่วนตัว"

, "Edit birthday, account data and other private information of employee records"
: "แก้ไขวันเกิด ข้อมูลปัญชีและความเป็๋นส่วนตัวอื่น ๆ ของบันทึกลูกจ้าง"

, "Public Holiday Calendar"
: ""

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: ""

, "Public Holidays"
: ""

, "Badge ID"
: ""

, "Human Resources"
: ""

, "Extra free time"
: "เวลาว่างพิเศษ"

, "Employee"
: "ลูกจ้าง"

, "CostCenter"
: "ศูนย์ต้นทุน"

, "Cost Center"
: "ศูนย์ต้นทุน"

, "Contract"
: "สัญญา"

, "Personal account"
: "บัญชีส่วนตัว"

, "Daily Working Time Report"
: ""

, "Working time"
: ""

, "Free Time"
: "เวลาที่ว่าง"

, "Free Day"
: "วันหยุด"

, "Break"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
